@@ -100,9 +100,11 @@ setMethod("glgm",
           covariates,
           buffer=0)
       
-      callGeneric(dataCov$formula, 
-          dataCov$data, dataCov$grid, 
-          dataCov$covariates, ...)
+      callGeneric(
+			  formula = dataCov$formula, 
+          data = dataCov$data, 
+		  grid = dataCov$grid, 
+          covariates = dataCov$covariates, ...)
     }
 )
 
@@ -134,18 +136,18 @@ setMethod("glgm",
 				shape=1, priorCI=NULL, 
 				mesh=FALSE,...) {
 
-      if(!any(names(grid)=='space'))
-				warning("grid must have a layer called space with inla cell ID's")
+    if(!any(names(grid)=='space'))
+		warning("grid must have a layer called space with inla cell ID's")
 
-			if(!all(all.vars(formula)%in% names(data)))
-				warning("some covariates seem to be missing: formula ", paste(all.vars(formula), collapse=" "), ", data: ", paste(names(data), collapse=" "))
+	if(!all(all.vars(formula)%in% names(data)))
+		warning("some covariates seem to be missing: formula ", paste(all.vars(formula), collapse=" "), ", data: ", paste(names(data), collapse=" "))
 
-      cells = trim(grid[['space']])
-			firstCell = values(cells)[1]
-			cellDim = dim(cells)[1:2]
-			# first cell = 2 * buffer^2 + ncolSmall * buffer + buffer
-			# buffer = -(nrowSmall+1) + sqrt (  (nrowSmall+1)^2 + 8 firstCell / 4
-			buffer = (-(cellDim[1]+1) + sqrt(  (cellDim[1]+1)^2 + 8* (firstCell-1) ))/4
+    cells = trim(grid[['space']])
+	firstCell = values(cells)[1]
+	cellDim = dim(cells)[1:2]
+	# first cell = 2 * buffer^2 + ncolSmall * buffer + buffer
+	# buffer = -(nrowSmall+1) + sqrt (  (nrowSmall+1)^2 + 8 firstCell / 4
+	buffer = (-(cellDim[1]+1) + sqrt(  (cellDim[1]+1)^2 + 8* (firstCell-1) ))/4
 	# data, cells, and covariates must have varilable called 'space'		
 	# values of cells must be index numbers, and cells shouldnt include the buffer		
 	thedots = list(...)
