@@ -2,7 +2,7 @@
 
 informationLgm = function(fit, ...) {
 	nonLinearParams = c('boxcox','shape','nugget','variance',
-			'anisoAngleDegrees','anisoRatio','range')
+			'anisoAngleRadians','anisoRatio','range')
 	
 	reEstimate = rownames(fit$summary)[
 			fit$summary[,"Estimated"]
@@ -12,10 +12,10 @@ informationLgm = function(fit, ...) {
 	reEstimate = gsub("range \\(km\\)", "range", reEstimate)
 	reEstimate = intersect(reEstimate, nonLinearParams)
 	
-	baseParam = fit$param[reEstimate]
-	moreParams = fit$param[
-			!names(fit$param) %in% reEstimate &
-					names(fit$param) %in% nonLinearParams]
+	baseParam = fit$parameters[reEstimate]
+	moreParams = fit$parameters[
+			!names(fit$parameters) %in% reEstimate &
+					names(fit$parameters) %in% nonLinearParams]
 	
 	parToLog = c("nugget","variance","anisoRatio","range")
 	parToLog = intersect(reEstimate, parToLog)
@@ -23,39 +23,60 @@ informationLgm = function(fit, ...) {
 	if(!all(baseParam[parToLog]>0))
 		return(list(summary=fit$summary,information=NULL))
 
-	
-	
-	
-	oneL = function(param, ...) {
+  # get rid of NA's
+  fit$data = na.omit(fit$data)
+  
+	aniso = length(grep("^aniso", reEstimate)) |
+      any(abs(moreParams['anisoRatio']-1) > 0.00001,na.rm=TRUE)
+  if(!aniso) {
+    coordinates = as(spDists(fit$data), 'dsyMatrix')  
+  } else{
+    coordinates=fit$data
+  }
+  
+	oneL = function(param) {
 #    parToExp = grep("^log\\(", names(param))
 #		param[parToExp] = exp(param[parToExp])
 #    names(param) = gsub("^log\\(|\\)$", "", names(param))
     param[parToLog] = exp(param[parToLog])
-		loglikLgm(param, ...)
+		loglikLgm(param, 
+        data=fit$data,
+        formula=fit$model$formula,
+        coordinates=coordinates,
+        reml=fit$model$reml,
+        moreParams=moreParams,
+        minustwotimes=FALSE)
 	}
 	
 	baseParam[parToLog] = log(baseParam[parToLog])
 	
-	# get rid of NA's
-	fit$data = na.omit(fit$data)
-	
-	hess = numDeriv::hessian(oneL, baseParam,
-			data=fit$data,formula=fit$model$formula,
-			reml=fit$model$reml,
-			moreParams=moreParams, ...)
+
+	hess = numDeriv::hessian(oneL, baseParam, ...)
 	
 	whichLogged = which(names(baseParam)%in% parToLog)
 	names(baseParam)[whichLogged] = paste("log(", 
 			names(baseParam)[whichLogged], ")",sep="")
 	
 	dimnames(hess) = list(names(baseParam),names(baseParam))
-	infmat = try(solve(hess), silent=TRUE)
+  
+  infmat = -hess
+  infmat = try(solve(infmat), silent=TRUE)
   if(class(infmat)=='try-error') {
 #    stuff <<- fit
     return(list(summary=fit$summary,information=NULL, error=infmat))
   } 
-    infmat = infmat*2
-	
+
+  
+  if(length(grep("anisoAngleRadians", colnames(infmat))) ) {
+  anisoAngleDegrees = (360/(2*pi))*infmat[,'anisoAngleRadians']
+  infmat = rbind(infmat, anisoAngleDegrees=anisoAngleDegrees)
+  anisoAngleDegrees = c(anisoAngleDegrees,
+      anisoAngleDegrees = (360/(2*pi))*
+          as.numeric(anisoAngleDegrees['anisoAngleRadians'])
+  )
+  infmat = cbind(infmat, anisoAngleDegrees=anisoAngleDegrees)  
+  }
+  
 	pvec = grep("^ci([[:digit:]]|\\.)+$", colnames(fit$summary),
 			value=TRUE)
 	pvec = as.numeric(gsub("^ci","", pvec))
@@ -63,7 +84,10 @@ informationLgm = function(fit, ...) {
 	names(qvec) = paste("ci", pvec, sep="")
 	
 	stdErr = diag(infmat)
-	if(any(stdErr<0))
+  if(any(is.na(stdErr)))
+    return(list(summary=fit$summary,information=infmat))
+    
+	if(!all(stdErr>0))
 		return(list(summary=fit$summary,information=infmat))
 	stdErr = sqrt(stdErr)
 	
@@ -88,7 +112,11 @@ informationLgm = function(fit, ...) {
 				sdSpatial = sqrt(
 						pmax(0,forSummary["variance",]))
 		)
-	
+
+  if(any(rownames(forSummary)=='anisoAngleRadians'))
+    forSummary = rbind(forSummary,
+        anisoAngleDegrees = forSummary['anisoAngleRadians',]*360/(2*pi)
+    )
 	
 	inBoth = intersect(rownames(summary), rownames(forSummary))
 	
