@@ -19,12 +19,22 @@ lgcp = function(formula=NULL, data,  grid, covariates=NULL,
 	
 # create data
 	
-	counts = rasterize(SpatialPoints(data), cells, fun="count")
+	if(!missing(border)) {
+		inBorder = over(
+				data, 
+				as(border, 'SpatialPolygons')
+		)
+		data = data[!is.na(inBorder),]
+	}
+	
+	counts = rasterize(
+			SpatialPoints(data), 
+			cells, fun="count")
 	names(counts) = "count"
 	counts[is.na(counts)] = 0
 	
 	if(!missing(border)) {
-		counts = mask(counts, border)
+		counts = raster::mask(counts, border)
 	}
 	
 # the formula	
